@@ -786,10 +786,10 @@ class BipartiteBase(DataFrame):
         Generate cdfs of compensation for firms.
 
         Arguments:
-            cdf_resolution (int): how many values to use to approximate the cdf
+            cdf_resolution (int): how many values to use to approximate the cdfs
             grouping (str): how to group the cdfs ('quantile_all' to get quantiles from entire set of data, then have firm-level values between 0 and 1; 'quantile_firm_small' to get quantiles at the firm-level and have values be compensations if small data; 'quantile_firm_large' to get quantiles at the firm-level and have values be compensations if large data, note that this is up to 50 times slower than 'quantile_firm_small' and should only be used if the dataset is too large to copy into a dictionary)
             stayers_movers (str or None): if None, uses entire dataset; if 'stayers', uses only stayers; if 'movers', uses only movers
-            t (int or None): if None, uses entire dataset; if int, gives time in data to consider (only valid for non-collapsed data)
+            t (int or None): if None, clusters on entire dataset; if int, gives period in data to consider (only valid for non-collapsed data)
             weighted (bool): if True, compute firm weights
 
         Returns:
@@ -887,11 +887,6 @@ class BipartiteBase(DataFrame):
                     # Update cdfs with the firm-level cdf
                     cdfs[i, j] = y[index]
 
-        if len(to_list(self.reference_dict['j'])) == 2: # Unstack Event Study
-            # Drop rows that were appended earlier and rename columns
-            data = data[data['j2'] >= 0]
-            data = data.rename({'j': 'j1', 'y': 'y1'}, axis=1)
-
         return cdfs, weights, jids
 
     def cluster(self, user_cluster={}):
@@ -903,13 +898,13 @@ class BipartiteBase(DataFrame):
 
                 Dictionary parameters:
 
-                    cdf_resolution (int): how many values to use to approximate the cdf
+                    cdf_resolution (int): how many values to use to approximate the cdfs
 
                     grouping (str): how to group the cdfs ('quantile_all' to get quantiles from entire set of data, then have firm-level values between 0 and 1; 'quantile_firm_small' to get quantiles at the firm-level and have values be compensations if small data; 'quantile_firm_large' to get quantiles at the firm-level and have values be compensations if large data, note that this is up to 50 times slower than 'quantile_firm_small' and should only be used if the dataset is too large to copy into a dictionary)
 
-                    stayers_movers (str or None): if None, uses entire dataset; if 'stayers', uses only stayers; if 'movers', uses only movers
+                    stayers_movers (str or None): if None, clusters on entire dataset; if 'stayers', clusters on only stayers; if 'movers', clusters on only movers
 
-                    t (int or None): if None, uses entire dataset; if int, gives time in data to consider (only valid for non-collapsed data)
+                    t (int or None): if None, clusters on entire dataset; if int, gives period in data to consider (only valid for non-collapsed data)
 
                     weighted (bool): if True, weight firm clusters by firm size (if a weight column is included, firm weight is computed using this column; otherwise, each observation has weight 1)
 
@@ -952,6 +947,8 @@ class BipartiteBase(DataFrame):
                 g_col = 'g'
             elif len(to_list(self.reference_dict['j'])) == 2:
                 g_col = 'g' + str(i + 1)
+            print('j_col:', j_col)
+            print('g_col:', g_col)
             clusters_dict = {j_col: jids, g_col: clusters}
             clusters_df = pd.DataFrame(clusters_dict, index=np.arange(len(jids)))
             frame.logger.info('dataframe linking fids to clusters generated')
